| more | R Documentation |
This function is a utility to add "filler" rows to the bottom of a data.frame. Basically an ellipsis ("...") for tabular data.
more(.data, fill = ".", extra_rows = 4)
.data |
Original |
fill |
Character vector of length 1 specifying the content to fill the extra rows; default is |
extra_rows |
Numeric vector of length 1 indicating how many rows of filler content should be added to the original |
A tibble with as many rows as the original input (.data) plus the number of extra rows (extra_rows), all of which are populated with the "filler" (fill) content in every column
more(head(mtcars)) rbind(more(head(mtcars, 1), fill = ".", extra_rows = 1), tail(mtcars, 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.